function sol = solveMultiClassKnapsack(instance)

% solution vector is composed in this way
% [edge_1 edge_2 edge_3 ... edge_n]
% edge_k = [x_(k,1) x_(k,2) ... x_(k,n[k])]
% where x_(k,w) is the binary variable for item w in edge (class) k
% and n[k] is the number of itesm in edge (class) k

% order convention: edge, item
% inequality constraints and objective function
f = [];
A = [];
n_variables = 0;
n_edges = size(instance.edges,2);
b = instance.T;
for k = 1:n_edges
    n_items = numel(instance.edges{k}.w);    
    n_variables = n_variables + n_items;
    f = [f ; instance.edges{k}.v'];
    A = [A instance.edges{k}.w];
end

% equality constraints
start = 1;
Aeq = zeros(n_edges,n_variables);
for k = 1:n_edges
    n_items = numel(instance.edges{k}.w);
    Aeq(k,start:start+n_items-1) = ones(1,n_items);
    start = start + n_items;    
end
beq = ones(n_edges,1);

% solve
sol = bintprog(f,A,b,Aeq,beq);